@@ -257,67 +257,75 @@ end interface
 
 interface !< writer.f90
 
-module subroutine h5write_scalar(self, dname, A, compact)
+module subroutine h5write_scalar(self, dname, A, compact, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in) :: A
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
-module subroutine h5write_1d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims)
+module subroutine h5write_1d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in), dimension(:) :: A
 integer, intent(in), dimension(1), optional :: chunk_size, istart, iend, stride, dset_dims
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
-module subroutine h5write_2d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims)
+module subroutine h5write_2d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in), dimension(:,:) :: A
 integer, intent(in), dimension(2), optional :: chunk_size, istart, iend, stride, dset_dims
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
-module subroutine h5write_3d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims)
+module subroutine h5write_3d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in), dimension(:,:,:) :: A
 integer, intent(in), dimension(3), optional :: chunk_size, istart, iend, stride, dset_dims
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
-module subroutine h5write_4d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims)
+module subroutine h5write_4d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in), dimension(:,:,:,:) :: A
 integer, intent(in), dimension(4), optional :: chunk_size, istart, iend, stride, dset_dims
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
-module subroutine h5write_5d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims)
+module subroutine h5write_5d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in), dimension(:,:,:,:,:) :: A
 integer, intent(in), dimension(5), optional :: chunk_size, istart, iend, stride, dset_dims
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
-module subroutine h5write_6d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims)
+module subroutine h5write_6d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in), dimension(:,:,:,:,:,:) :: A
 integer, intent(in), dimension(6), optional :: chunk_size, istart, iend, stride, dset_dims
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
-module subroutine h5write_7d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims)
+module subroutine h5write_7d(self, dname, A, chunk_size, istart, iend, stride, compact, dset_dims, datatype)
 class(hdf5_file), intent(in) :: self
 character(*), intent(in) :: dname
 class(*), intent(in), dimension(:,:,:,:,:,:,:) :: A
 integer, intent(in), dimension(7), optional :: chunk_size, istart, iend, stride, dset_dims
 logical, intent(in), optional :: compact
+integer(HID_T), intent(in), optional :: datatype
 end subroutine
 
 end interface
