@@ -24,7 +24,7 @@ call h5fcreate_f(filename, H5F_ACC_TRUNC_F, lid, i)
 if (i/=0) error stop 'minimal: could not create file'
 print *, 'minimal: created '//filename
 
-call h5ltmake_dataset_f(lid, "A", rank(p), shape(p, kind=HSIZE_T), h5kind_to_type(kind(p),H5_INTEGER_KIND), p, i)
+call h5ltmake_dataset_f(lid, "A", 0, shape(p, kind=HSIZE_T), h5kind_to_type(kind(p),H5_INTEGER_KIND), p, i)
 if (i/=0) error stop 'minimal: could not create dataset A'
 print *, 'minimal: created variable'
 
